@@ -3,8 +3,8 @@
 
 from bitarray import bitarray, frozenbitarray
 
-from RVFormatParser import RVFormatParser as fp
-from RVInstruction import RVInstruction
+from . import RVFormatParser as fp
+from . import RVInstruction
 
 
 class V32:
